@@ -24,7 +24,6 @@ class GeoDataType:
 
 
 class AccessionDownloader:
-
     def __init__(self, accession_save_filepath: str = None, history_dir: str = None):
         self.session = Session()
         headers = {
@@ -135,7 +134,6 @@ class GeoDownloader:
     @Timeit(prefix='成功读取并完成过滤')
     def filter_request_list(self, request_list: set, desc: str = 'Accession'):
         """ 读取并过滤 request 列表 """
-        print('-*-' * 22)
         print(f'正在读取 {desc} 列表')
         total_request_count = len(request_list)
         filter_string = f'\t--> 共有 {desc} 数量：{total_request_count}'
@@ -157,7 +155,7 @@ class GeoDownloader:
         else:
             self.error_f = open(self.error_filepath, mode='a+')
         print(filter_string)
-        print('-*-' * 22)
+
         return request_list
 
     def download_series_matrix_url(self, accession_list: Iterable = None, series_matrix_url_filepath: str = None,
@@ -171,7 +169,9 @@ class GeoDownloader:
         self.series_matrix_url_filepath = series_matrix_url_filepath if series_matrix_url_filepath else f'{self.history_dir}/series_matrix_urls.txt'
         self.series_matrix_url_f = open(self.series_matrix_url_filepath, mode='a')
         while True:
+            print('-*-' * 22)
             accession_list = self.filter_request_list(request_list=accession_list, desc='Accession')
+            print('-*-' * 22)
             if len(accession_list) > 0:
                 if async_on:
                     asyncio.run(self.download_series_matrix_url_init_async())
@@ -330,7 +330,6 @@ class GeoParser:
     @Timeit(prefix='成功读取并完成过滤')
     def filter_list(self, all_list: set, desc: str = '文件'):
         """ 读取并过滤 列表 """
-        print('-*-' * 22)
         print(f'正在读取 {desc} 列表')
         total_count = len(all_list)
         filter_string = f'\t--> 共有 {desc} 数量：{total_count}'
@@ -352,7 +351,6 @@ class GeoParser:
         else:
             self.error_f = open(self.error_filepath, mode='a+')
         print(filter_string)
-        print('-*-' * 22)
         return all_list
 
     def func_map_init(self):
@@ -374,7 +372,10 @@ class GeoParser:
         if not os.path.exists(self.series_matrix_table_dir):
             os.mkdir(self.series_matrix_table_dir)
 
-        return self.filter_list(all_list=file_list, desc='文件')
+        print('-*-' * 22)
+        filter_file_list = self.filter_list(all_list=file_list, desc='文件')
+        print('-*-' * 22)
+        return filter_file_list
 
     def parse_series_matrix(self, filepath: str):
         filename = os.path.split(filepath)[-1]
